@@ -16,7 +16,7 @@ import sys
 
 # Importar solo los tabs esenciales que existen
 from .tabs.batch_processor_tab import BatchProcessingTab
-from .tabs.advanced_ml_tab import AdvancedMLTabWithFeatureSelection
+from .tabs.advanced_ml_tab import AdvancedMLTabWithPlots
 
 # Configurar logging
 logging.basicConfig(
@@ -111,7 +111,7 @@ class VacancyPredictorApp:
         
         # 2. TAB DE ADVANCED ML
         try:
-            self.advanced_ml_tab = AdvancedMLTabWithFeatureSelection(self.notebook, self.on_advanced_data_loaded)
+            self.advanced_ml_tab = AdvancedMLTabWithPlots(self.notebook, self.on_advanced_data_loaded)
             self.notebook.add(self.advanced_ml_tab.frame, text="Advanced ML")
         except Exception as e:
             logger.error(f"Error creating ML tab: {e}")
@@ -218,7 +218,6 @@ class VacancyPredictorApp:
         
         if file_path:
             try:
-                import pandas as pd
                 if file_path.endswith('.xlsx'):
                     data = pd.read_excel(file_path)
                 else:
